# make -f lin_bsf4rexx-32.mak rebuild
#
# ------------------------ Apache Version 2.0 license -------------------------
#    Copyright (C) 2001-2009 Rony G. Flatscher
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.
# -----------------------------------------------------------------------------

#-------------------------------------------------------------------------
# linux_bsf4rexx_regina.mak: makefile to build libBSF4ooRexx.so
#
# ooRexx 4.x, 2005-06-07, 2009-09-08
#
# make -f lin_bsf4rexx [orexx | clean | clean_dll | rebuild ]
#-------------------------------------------------------------------------

# -----------------------  Path Definitions  ----------------------------
BLD_PATH = .

JDK_BASE = /Library/Java/Home

INC_PATH = -I$(JDK_BASE)/include

INC_PATH_ORX = -I/opt/ooRexx/include $(INC_PATH)

LIB_PATH = -L/opt/ooRexx/lib/ooRexx


# --------------------------------------------------------
del_cmd  = rm -f

copy_cmd = cp

ORX     = OREXX
BSF_SRC	= BSF4ooRexx.cc


#
# Compiler macros
#
cc = gcc -fPIC
link = gcc

CFLAGS		= -c -O3 -D__cplusplus -DUNIX -m32 -DBSF4REXX_32_BIT

CFLAGS_ORX      = -DUSE_$(ORX)

LINK_FLAGS      = --export-dynamic -shared -rdynamic -lpthread -lc  -lm


LINK_ORX_FLAGS  = -lrexx -lrexxapi -lrexxutil

BSF_OBJ_ORX     = $(BLD_PATH)/BSF4ooRexx-32.o
BSF_ORX_TARGET  = $(BLD_PATH)/libBSF4ooRexx-32.dylib
BSF4REXX	= $(BLD_PATH)/libBSF4ooRexx.dylib

# *************************************************************************** #
# Rules									      #
# *************************************************************************** #
# .cc.o:
#	  $(cc) $(CFLAGS) -o$*.o $(INC_PATH) $(LIB_PATH) $*.cc

#---------------------------------------------------------- Generate library

# Object Rexx ----------------------------------------------
$(BSF_ORX_TARGET) : $(BSF_SRC)
	echo
	echo Building $@ ...
	echo
	$(cc) $(CFLAGS) $(CFLAGS_ORX) -o$(BSF_OBJ_ORX) $(INC_PATH) $(INC_PATH_ORX) $(LIB_PATH) $(BSF_SRC)
	$(link) -Wl,-dylib_install_name,$@ -o $(BLD_PATH)/$@ $(BSF_OBJ_ORX) \
	$(LIB_PATH) $(LINK_FLAGS) $(LINK_ORX_FLAGS)
	$(copy_cmd) $(BSF_ORX_TARGET) $(BSF4REXX)
	$(copy_cmd) $(BSF4REXX) 32
#	$(copy_cmd) $(BSF4REXX) ../bsf4rexx


#---------------------------------------------------------- END section
orexx :		$(BSF_ORX_TARGET)

#---------------------------------------------------------- END section
# -------------------------------------------------------------------
# builds all
rebuild: clean clean_dll orexx

#---------------------------------------------------------- END section
# just clean up the mess, just leave the dll
clean:
	- $(del_cmd) $(BLD_PATH)/*.o

#---------------------------------------------------------- END section
clean_dll:
	- $(del_cmd) $(BLD_PATH)/*.dylib


# -------------------------------------------------------------------
# builds all
all: clean orexx

# -------------------------------------------------------------------
i:
	$(cc) $(CFLAGS) $(CFLAGS_ORX) -oBSF4ooRexx.i $(INC_PATH) $(INC_PATH_ORX) -E $(LIB_PATH) $(BSF_SRC)
